### si:constant Examples


##### The “constant” quantity data model has the same basic structure as the atomic “real” quantity. This comprises the mandatory statement of a “value” component together with the associated “unit” component.
##### The “label” component is used to identify the constant. The “dataTime” component is of great importance for the definition of fundamental physical constants. The latest values of these fundamental constants are regularly published by CODATA [[4]](https://physics.nist.gov/cuu/pdf/wall_2018.pdf). The “dateTime” element allows to identify to which release of CODATA the constant is associated.
##### The constants are distinguished into those constants with an exact numerical value and constants with an uncertainty attributed to the numerical value. The uncertainty value is implemented as component “uncertainty” in the constant data model. Its value refers to the unit element that is also valid for the value element.
<!--The quantity value is expressed by the [si:value](comp/value.md) element and the [si:unit](comp/unit.md) element. Optional elements are [si:label](comp/label.md), [si:dateTime](comp/dateTime.md) element, [si:uncertainty](comp/uncertainty.md) element, and [si:distribution](comp/distribution.md) element.-->
##### Note: The definition of uncertainty, datetime and distribution differ from those in [si:real](real_example.md).

##### Additional information relevant for uncertainty definition of [si:constant](constant_example.md)
The value of the “uncertainty” component shall provide the standard deviation for values from CODATA. In addition, the distribution of the uncertainty, if known, can be provided in the component “distribution”.

Mathematical constants play a special role. Numbers like pi or the Euler number are irrational numbers. They require rounding to a finite number of digits for a machine representation. The rounding leads to a rounding error that shall be expressed by a rectangular distribution that contains the true value of the constant with 100% probability. The rectangular distribution shall be centred at the numerical value that is provided by the element value. The component “uncertainty” shall give the standard uncertainty value of the rectangular distribution. 

##### Additional information relevant for dateTime of [si:constant](constant_example.md)
The “dataTime” component is of great importance for the definition of fundamental physical constants. The latest values of these fundamental constants are regularly published by CODATA the constant is associated.

##### Additional information for distribution of [si:constant](constant_example.md)
The distribution component is defined with the text “rectangular” indicating an uncertainty for a rectangular distributed quantity.

##### The two examples show Planck constant in two different representaions. 

```xml
<si:constant> 
    <si:label>Planck constant</si:label> 
    <si:value>6.62607015e-34</si:value> 
    <si:unit>\joule\hertz\tothe{-1}</si:unit> 
    <si:dateTime>2019-05-20T00:00:00Z</si:dateTime> 
    <si:uncertainty>0</si:uncertainty> 
</si:constant>
```
```xml
<si:constant>
    <si:label>Planck constant</si:label>
    <si:value>6.62607015e-34</si:value> 
    <si:unit>\joule\hertz\tothe{-1}</si:unit> 
    <si:dateTime>2019-05-20T00:00:00Z</si:dateTime> 
    <si:uncertainty>8.1e-42</si:uncertainty>
    <si:distribution>normal</si:distribution>
</si:constant>
```
##### The example shows PI in the singel precision format.
```xml
<si:constant>
    <si:label>pi in single precision format</si:label>
    <si:value>3.1415927</si:value>
    <si:unit>\one</si:unit>
    <si:uncertainty>0.000000051</si:uncertainty>
    <si:distribution>rectangular</si:distribution>
</si:constant>
```

##### The XSD scheme for the [si:constant](constant_example.md) is presented below. The solid lines of the frame represents mandatory requirements, while the dashed lines of the frame represent optional requirements.

<img src="pic/planckconst_xsd.png" alt="" width=""/>

[back to home](https://gitlab1.ptb.de/d-ptb/d-si/xsd-d-si/tree/feat-online-guide/wiki/d-si-online-guide.md)